"""adding grey 2

Revision ID: e976e9d6d502
Revises: a18b186b0291
Create Date: 2025-08-14 01:37:53.591749

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = 'e976e9d6d502'
down_revision: Union[str, Sequence[str], None] = 'a18b186b0291'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    """Upgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.execute("ALTER TYPE colors ADD VALUE 'GRAY';")
    pass
    # ### end Alembic commands ###


def downgrade() -> None:
    """Downgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
