"""pixel test

Revision ID: 3cba87a8b28a
Revises: 8e015abbe587
Create Date: 2025-07-29 11:55:33.323950

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = '3cba87a8b28a'
down_revision: Union[str, Sequence[str], None] = '8e015abbe587'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    """Upgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    # op.add_column('users', sa.Column('pixels', sa.Integer(), nullable=False))
    op.add_column('users', sa.Column('pixels', sa.Integer(), nullable=False, server_default='5'))
    # ### end Alembic commands ###


def downgrade() -> None:
    """Downgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('users', 'pixels')
    # ### end Alembic commands ###
